=======
History
=======

2021.2.10 (10 February 2021)
----------------------------

* Updated the README file to give a better description.
* Updated the short description in setup.py to work with the new installer.
* Added keywords for better searchability.

2020.8.1 (1 August 2020)
------------------------

* Added support for OpenKIM potentials in LAMMPS

0.9.1 (24 May 2020)
-------------------

* Added the specialized NaCl_water forcefield for testing the MolSSI
  Driver Interface (MDI) metadynamics driver.

0.9 (15 April 2020)
-------------------

* Internal changes for compatibility
  
0.1.0 (24 December 2017)
------------------------

* First release on PyPI.
